-- name: \\#8FB9CC\\[CS] Midna
-- description: Midna v1.0\nCreated and modeled by NaNpuni.\n\nYou need the Character Select mod.\nType /char-select to select.

local MOD_VERSION = _G.charSelect.version_get()
local MAJOR, MINOR, PATCH = string.match(MOD_VERSION, "(%d+)%.(%d+)%.?(%d*)")
MAJOR, MINOR, PATCH = tonumber(MAJOR), tonumber(MINOR), tonumber(PATCH) or 0
local V1_8_OR_ABOVE = MAJOR > 1 or (MAJOR == 1 and MINOR >= 8)

local TEXT_MOD_NAME = "Midna"
local TEX = get_texture_info("icon")
local E_MODEL = smlua_model_util_get_id("geo")
local CAPTABLE = {
    normal = smlua_model_util_get_id("cap_geo"),
    wing = smlua_model_util_get_id("wing_cap_geo"),
    metal = smlua_model_util_get_id("metal_cap_geo"),
    metalWing = smlua_model_util_get_id("metal_wing_cap_geo"),
}
local VOICETABLE = {
    [CHAR_SOUND_ATTACKED] = {'attacked1.mp3', 'attacked2.mp3', 'attacked3.mp3'},
	[CHAR_SOUND_COUGHING1] = 'coughing1.mp3',
    [CHAR_SOUND_COUGHING2] = 'coughing2.mp3',
	[CHAR_SOUND_COUGHING3] = 'coughing3.mp3',
    [CHAR_SOUND_DOH] = 'doh1.mp3', -- Bonk into walls
	[CHAR_SOUND_DROWNING] = 'drowning1.mp3',
    [CHAR_SOUND_DYING] = {'dying1.mp3', 'dying2.mp3'},
    [CHAR_SOUND_EEUH] = {'get_up_ledge1.mp3',}, -- Slow Get up from ledge
    --[CHAR_SOUND_GAME_OVER] = {'silent.mp3'},
    [CHAR_SOUND_GROUND_POUND_WAH] = {'ground_pound1.mp3', 'ground_pound2.mp3',},
    [CHAR_SOUND_HAHA] = {'landing_backflip1.mp3', 'landing_backflip2.mp3'}, -- Landing after backflip
    [CHAR_SOUND_HAHA_2] = 'landing_water1.mp3', -- Landing on Water after a fall
    [CHAR_SOUND_HELLO] = 'hello.mp3',
    [CHAR_SOUND_HERE_WE_GO] = {'star_get_or_power1.mp3'}, -- Star Get + Obtaining Power-up
    [CHAR_SOUND_HOOHOO] = 'double_jump1.mp3', -- 2nd Jump + Dive Attack
    [CHAR_SOUND_HRMM] = 'object_pick1.mp3', -- Object Pick-up
    [CHAR_SOUND_IMA_TIRED] = 'ima_tired1.mp3',
    [CHAR_SOUND_LETS_A_GO] = 'level_select1.mp3', -- Level Select
    [CHAR_SOUND_MAMA_MIA] = 'throw_out_level1.mp3', -- Getting up after thrown out of level
	[CHAR_SOUND_OKEY_DOKEY] = 'okey_dokey.mp3',
    [CHAR_SOUND_ON_FIRE] = {'touch_fire1.mp3',}, -- Touch Fire
    [CHAR_SOUND_OOOF] = 'ooof1.mp3',
    [CHAR_SOUND_OOOF2] = 'ooof2.mp3', -- Landing After a Bonk + Thrown out of level
    [CHAR_SOUND_PANTING] = {'pant.mp3',}, -- Low Health
    [CHAR_SOUND_PANTING_COLD] = 'panting_cold.mp3',
    --[CHAR_SOUND_PRESS_START_TO_PLAY] = {'silent.mp3', 'silent.mp3'},
    [CHAR_SOUND_PUNCH_HOO] = {'kick1.mp3','kick2.mp3'}, -- Kick
    [CHAR_SOUND_PUNCH_WAH] = 'punch2.mp3', -- 2nd Punch
    [CHAR_SOUND_PUNCH_YAH] = 'punch1.mp3', -- 1st Punch
    [CHAR_SOUND_SNORING1] = 'snoring1.mp3',
    [CHAR_SOUND_SNORING2] = 'snoring2.mp3',
    [CHAR_SOUND_SNORING3] = {'snoring3.mp3', 'snoring4.mp3'},
    [CHAR_SOUND_SO_LONGA_BOWSER] = {'bowser_throw1.mp3', 'bowser_throw2.mp3'}, -- Bowser Throw
    [CHAR_SOUND_TWIRL_BOUNCE] = {'boing1.mp3'}, -- Boing
    [CHAR_SOUND_UH] = 'drop_ledge1.mp3', -- Drop off of ledge
    [CHAR_SOUND_UH2] = {'drop_ledge1.mp3',}, -- ???
    [CHAR_SOUND_UH2_2] = 'landing_long_jump1.mp3', -- Landing after Long Jump
    [CHAR_SOUND_WAAAOOOW] = 'falling1.mp3', -- Falling
    [CHAR_SOUND_WAH2] = 'throw_object1.mp3', -- Throw Object
    [CHAR_SOUND_WHOA] = 'ledge_grab1.mp3', -- Ledge Grab
    [CHAR_SOUND_YAHOO] = {'long_jump1.mp3',}, -- Long Jump
    [CHAR_SOUND_YAHOO_WAHA_YIPPEE] = 'triple_jump1.mp3', -- 3rd Jump
    [CHAR_SOUND_YAH_WAH_HOO] = {'jump1.mp3', 'jump2.mp3', 'jump3.mp3'}, -- 1st Jump
    [CHAR_SOUND_YAWNING] = 'yawn1.mp3',
}

-- Function aliases
local char_add = _G.charSelect.character_add
local char_add_voice = _G.charSelect.character_add_voice
local char_get_voice = _G.charSelect.character_get_voice
local voice_sound = _G.charSelect.voice.sound
local voice_snore = _G.charSelect.voice.snore
local char_add_caps = _G.charSelect.character_add_caps
local char_add_palette_preset = nil

if _G.charSelectExists then
    char_add(
		"Midna",
		{
			"The Twilight Princess in Imp form.",
		},
		"NaNpuni",
		{r = 50, g = 225, b = 204},
		E_MODEL, CT_MARIO, TEX
	)

-- All Caps and Voices
	char_add_caps(E_MODEL, CAPTABLE)
    char_add_voice(E_MODEL, VOICETABLE)

    hook_event(HOOK_CHARACTER_SOUND, function (m, sound)
        if char_get_voice(m) == VOICETABLE then return voice_sound(m, sound) end
    end)
    hook_event(HOOK_MARIO_UPDATE, function (m)
        if char_get_voice(m) == VOICETABLE then return voice_snore(m) end
    end)
else
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
end